<?php

namespace Drp\SimpleCms\Http\Requests;

use Drp\SimpleCms\Contracts\Publishable;
use Illuminate\Contracts\Validation\Validator;
use Illuminate\Foundation\Http\FormRequest;
use Illuminate\Validation\ValidationException;

/**
 * Class ContentRequest
 * @package Drp\SimpleCms
 */
class ContentRequest extends FormRequest implements \Drp\SimpleCms\Contracts\ContentRequest
{
    /**
     * @var The save validation rules
     */
    protected $rules = [];

    /**
     * @var The save validation messages
     */
    protected $messages = [];

    /**
     * Prepare the input using the given content.
     * Retrieves the before updated closure from the content
     * and calls it using the current request.
     *
     * @param Publishable $content
     * @return array|string
     */
    public function prepareInput(Publishable $content)
    {
        $this->prepareValidation($content);

        $callback = $content->getCallbackForUpdateRequest($this);

        if ($callback instanceof \Closure) {
            call_user_func($callback, $this);
        }
        return $this->input();
    }

    /**
     * Prepare the validation rules and message for the content type
     *
     * @param Publishable $content
     * @return void
     */
    public function prepareValidation(Publishable $content)
    {
        $this->rules = $content->getSaveRules();
        $this->messages = $content->getSaveMessages();
    }

    /**
     * Determine if the user is authorized to make this request.
     *
     * @return boolean
     */
    public function authorize()
    {
        return true;
    }

    /**
     * Get the validation rules that apply to the request.
     *
     * @return array
     */
    public function rules()
    {
        return $this->rules;
    }

    /**
     * Get custom messages for validator errors.
     *
     * @return array
     */
    public function messages()
    {
        return $this->messages;
    }
}
